@@ -507,7 +507,7 @@ class Map(folium.Map):
         except Exception:
             raise Exception("Failed to add the specified TileLayer.")
 
-    def add_COG_layer(
+    def add_cog_layer(
         self,
         url,
         name="Untitled",
@@ -527,8 +527,8 @@ class Map(folium.Map):
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
             titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
         """
-        tile_url = get_COG_tile(url, titiler_endpoint, **kwargs)
-        center = get_COG_center(url, titiler_endpoint)  # (lon, lat)
+        tile_url = get_cog_tile(url, titiler_endpoint, **kwargs)
+        center = get_cog_center(url, titiler_endpoint)  # (lon, lat)
         self.add_tile_layer(
             tiles=tile_url,
             name=name,
@@ -538,7 +538,7 @@ class Map(folium.Map):
         )
         self.set_center(lon=center[0], lat=center[1], zoom=10)
 
-    def add_COG_mosaic(
+    def add_cog_mosaic(
         self,
         links,
         name="Untitled",
@@ -567,7 +567,7 @@ class Map(folium.Map):
             verbose (bool, optional): Whether or not to print descriptions. Defaults to True.
         """
         layername = name.replace(" ", "_")
-        tile = get_COG_mosaic(
+        tile = get_cog_mosaic(
             links,
             titiler_endpoint=titiler_endpoint,
             username=username,
@@ -584,7 +584,7 @@ class Map(folium.Map):
                 )
             coords = []
             for link in links:
-                coord = get_COG_bounds(link)
+                coord = get_cog_bounds(link)
                 if coord is not None:
                     coords.append(coord)
             fc = coords_to_geojson(coords)
@@ -601,11 +601,11 @@ class Map(folium.Map):
             if verbose:
                 print("The footprint layer has been added.")
         else:
-            center = get_COG_center(links[0], titiler_endpoint)
+            center = get_cog_center(links[0], titiler_endpoint)
 
         self.set_center(center[0], center[1], zoom=6)
 
-    def add_STAC_layer(
+    def add_stac_layer(
         self,
         url,
         bands=None,
@@ -626,8 +626,8 @@ class Map(folium.Map):
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
             titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
         """
-        tile_url = get_STAC_tile(url, bands, titiler_endpoint, **kwargs)
-        center = get_STAC_center(url, titiler_endpoint)
+        tile_url = get_stac_tile(url, bands, titiler_endpoint, **kwargs)
+        center = get_stac_center(url, titiler_endpoint)
         self.add_tile_layer(
             tiles=tile_url,
             name=name,
@@ -819,70 +819,162 @@ class Map(folium.Map):
         styled_vector = vector_styling(ee_object, column, palette, **kwargs)
         self.addLayer(styled_vector.style(**{"styleProperty": "style"}), {}, layer_name)
 
-    def add_shapefile(self, in_shp, name="Untitled", **kwargs):
+    def add_shapefile(self, in_shp, layer_name="Untitled", **kwargs):
         """Adds a shapefile to the map. See https://python-visualization.github.io/folium/modules.html#folium.features.GeoJson for more info about setting style.
 
         Args:
             in_shp (str): The input file path to the shapefile.
-            name (str, optional): The layer name to be used. Defaults to "Untitled".
+            layer_name (str, optional): The layer name to be used. Defaults to "Untitled".
 
         Raises:
             FileNotFoundError: The provided shapefile could not be found.
         """
+        in_shp = os.path.abspath(in_shp)
         if not os.path.exists(in_shp):
             raise FileNotFoundError("The provided shapefile could not be found.")
 
         data = shp_to_geojson(in_shp)
 
-        geo_json = folium.GeoJson(data=data, name=name, **kwargs)
+        geo_json = folium.GeoJson(data=data, name=layer_name, **kwargs)
         geo_json.add_to(self)
 
-    def add_geojson(self, in_geojson, name="Untitled", **kwargs):
+    def add_geojson(self, in_geojson, layer_name="Untitled", **kwargs):
         """Adds a GeoJSON file to the map.
 
         Args:
             in_geojson (str): The input file path to the GeoJSON.
-            name (str, optional): The layer name to be used. Defaults to "Untitled".
+            layer_name (str, optional): The layer name to be used. Defaults to "Untitled".
 
         Raises:
             FileNotFoundError: The provided GeoJSON file could not be found.
         """
         import json
+        import requests
 
-        if not os.path.exists(in_geojson):
-            raise FileNotFoundError("The provided GeoJSON file could not be found.")
+        try:
 
-        with open(in_geojson) as f:
-            data = json.load(f)
+            if isinstance(in_geojson, str):
 
-        geo_json = folium.GeoJson(data=data, name=name, **kwargs)
+                if in_geojson.startswith("http"):
+                    data = requests.get(in_geojson).json()
+                else:
+                    in_geojson = os.path.abspath(in_geojson)
+                    if not os.path.exists(in_geojson):
+                        raise FileNotFoundError(
+                            "The provided GeoJSON file could not be found."
+                        )
+
+                    with open(in_geojson) as f:
+                        data = json.load(f)
+            elif isinstance(in_geojson, dict):
+                data = in_geojson
+            else:
+                raise TypeError("The input geojson must be a type of str or dict.")
+        except Exception as e:
+            raise Exception(e)
+
+        geo_json = folium.GeoJson(data=data, name=layer_name, **kwargs)
         geo_json.add_to(self)
 
-    def add_kml(self, in_kml, name="Untitled", **kwargs):
+    def add_kml(self, in_kml, layer_name="Untitled", **kwargs):
         """Adds a KML file to the map.
 
         Args:
             in_kml (str): The input file path to the KML.
-            name (str, optional): The layer name to be used. Defaults to "Untitled".
+            layer_name (str, optional): The layer name to be used. Defaults to "Untitled".
 
         Raises:
             FileNotFoundError: The provided KML file could not be found.
         """
-        import json
+        # import json
 
+        in_kml = os.path.abspath(in_kml)
         if not os.path.exists(in_kml):
             raise FileNotFoundError("The provided KML file could not be found.")
 
-        out_json = os.path.join(os.getcwd(), "tmp.geojson")
+        # out_json = os.path.join(os.getcwd(), "tmp.geojson")
 
-        kml_to_geojson(in_kml, out_json)
+        data = kml_to_geojson(in_kml)
 
-        with open(out_json) as f:
-            data = json.load(f)
+        # with open(out_json) as f:
+        #     data = json.load(f)
 
-        geo_json = folium.GeoJson(data=data, name=name, **kwargs)
+        geo_json = folium.GeoJson(data=data, name=layer_name, **kwargs)
         geo_json.add_to(self)
-        os.remove(out_json)
+        # os.remove(out_json)
+
+    def add_osm(
+        self,
+        query,
+        layer_name="Untitled",
+        which_result=None,
+        by_osmid=False,
+        buffer_dist=None,
+        to_ee=False,
+        geodesic=True,
+        **kwargs,
+    ):
+        """Adds OSM data to the map.
+
+        Args:
+            query (str | dict | list): Query string(s) or structured dict(s) to geocode.
+            layer_name (str, optional): The layer name to be used.. Defaults to "Untitled".
+            style (dict, optional): A dictionary specifying the style to be used. Defaults to {}.
+            which_result (INT, optional): Which geocoding result to use. if None, auto-select the first (Multi)Polygon or raise an error if OSM doesn't return one. to get the top match regardless of geometry type, set which_result=1. Defaults to None.
+            by_osmid (bool, optional): If True, handle query as an OSM ID for lookup rather than text search. Defaults to False.
+            buffer_dist (float, optional): Distance to buffer around the place geometry, in meters. Defaults to None.
+            to_ee (bool, optional): Whether to convert the csv to an ee.FeatureCollection.
+            geodesic (bool, optional): Whether line segments should be interpreted as spherical geodesics. If false, indicates that line segments should be interpreted as planar lines in the specified CRS. If absent, defaults to true if the CRS is geographic (including the default EPSG:4326), or to false if the CRS is projected.
+
+        """
+
+        gdf = osm_to_geopandas(
+            query, which_result=which_result, by_osmid=by_osmid, buffer_dist=buffer_dist
+        )
+        geojson = gdf.__geo_interface__
+
+        if to_ee:
+            fc = geojson_to_ee(geojson, geodesic=geodesic)
+            self.addLayer(fc, {}, layer_name)
+            self.centerObject(fc)
+        else:
+            self.add_geojson(geojson, layer_name=layer_name, **kwargs)
+            bounds = gdf.bounds.iloc[0]
+            self.fit_bounds([[bounds[1], bounds[0]], [bounds[3], bounds[2]]])
+
+    def add_planet_by_month(
+        self, year=2016, month=1, name=None, api_key=None, token_name="PLANET_API_KEY"
+    ):
+        """Adds a Planet global mosaic by month to the map. To get a Planet API key, see https://developers.planet.com/quickstart/apis
+
+        Args:
+            year (int, optional): The year of Planet global mosaic, must be >=2016. Defaults to 2016.
+            month (int, optional): The month of Planet global mosaic, must be 1-12. Defaults to 1.
+            name (str, optional): The layer name to use. Defaults to None.
+            api_key (str, optional): The Planet API key. Defaults to None.
+            token_name (str, optional): The environment variable name of the API key. Defaults to "PLANET_API_KEY".
+        """
+        layer = planet_tile_by_month(
+            year, month, name, api_key, token_name, tile_format="folium"
+        )
+        self.add_layer(layer)
+
+    def add_planet_by_quarter(
+        self, year=2016, quarter=1, name=None, api_key=None, token_name="PLANET_API_KEY"
+    ):
+        """Adds a Planet global mosaic by quarter to the map. To get a Planet API key, see https://developers.planet.com/quickstart/apis
+
+        Args:
+            year (int, optional): The year of Planet global mosaic, must be >=2016. Defaults to 2016.
+            quarter (int, optional): The quarter of Planet global mosaic, must be 1-12. Defaults to 1.
+            name (str, optional): The layer name to use. Defaults to None.
+            api_key (str, optional): The Planet API key. Defaults to None.
+            token_name (str, optional): The environment variable name of the API key. Defaults to "PLANET_API_KEY".
+        """
+        layer = planet_tile_by_quarter(
+            year, quarter, name, api_key, token_name, tile_format="folium"
+        )
+        self.add_layer(layer)
 
     def publish(
         self,
